@@ -154,10 +154,18 @@ extern "C" {
 #  define MRN_HAVE_HA_EXTRA_STARTING_ORDERED_INDEX_SCAN
 #endif
 
+#if MYSQL_VERSION_ID >= 80017 && !defined(MRN_MARIADB_P)
+#  define MRN_HAVE_HA_EXTRA_ENABLE_UNIQUE_RECORD_FILTER
+#  define MRN_HAVE_HA_EXTRA_DISABLE_UNIQUE_RECORD_FILTER
+#endif
+
 #if MYSQL_VERSION_ID >= 50604 && !defined(MRN_MARIADB_P)
 #  define MRN_TIMESTAMP_USE_TIMEVAL
 #elif defined(MRN_MARIADB_P)
 #  define MRN_TIMESTAMP_USE_MY_TIME_T
+#  if MYSQL_VERSION_ID >= 100100
+#    define MRN_TIMESTAMP_USE_MY_TIME_T_AND_POS
+#  endif
 #else
 #  define MRN_TIMESTAMP_USE_LONG
 #endif
@@ -421,6 +429,10 @@ typedef uint mrn_alter_table_flags;
 #  define MRN_HANDLER_HAVE_COND_POP
 #endif
 
+#if MYSQL_VERSION_ID >= 80017 && !defined(MRN_MARIADB_P)
+#  define MRN_HANDLER_HAVE_HA_EXTRA
+#endif
+
 class ha_mroonga;
 
 /* structs */
@@ -618,7 +630,9 @@ public:
   int rnd_pos(uchar *buf, uchar *pos);                             // required
 #endif
   void position(const uchar *record);                              // required
-  int extra(enum ha_extra_function operation);
+#ifndef MRN_HANDLER_HAVE_HA_CLOSE
+  int extra(enum ha_extra_function operation) mrn_override;
+#endif
   int extra_opt(enum ha_extra_function operation, ulong cache_size);
 
   int delete_table(const char *name
@@ -960,6 +974,10 @@ private:
 #ifdef MRN_HANDLER_HAVE_HA_CLOSE
   int close();
 #endif
+#ifdef MRN_HANDLER_HAVE_HA_CLOSE
+  int extra(enum ha_extra_function operation) mrn_override;
+#endif
+
   bool is_dry_write();
   bool is_enable_optimization();
   bool should_normalize(Field *field, bool is_fulltext_index) const;
@@ -969,8 +987,6 @@ private:
   void check_fast_order_limit(grn_table_sort_key **sort_keys, int *n_sort_keys,
                               longlong *limit);
 
-  long long int get_grn_time_from_timestamp_field(Field_timestamp *field);
-
   int generic_store_bulk_fixed_size_string(Field *field, grn_obj *buf);
   int generic_store_bulk_variable_size_string(Field *field, grn_obj *buf);
   int generic_store_bulk_integer(Field *field, grn_obj *buf);
@@ -982,6 +998,9 @@ private:
   int generic_store_bulk_datetime(Field *field, grn_obj *buf);
   int generic_store_bulk_year(Field *field, grn_obj *buf);
   int generic_store_bulk_new_date(Field *field, grn_obj *buf);
+#ifdef MRN_HAVE_MYSQL_TYPE_TIMESTAMP2
+  int generic_store_bulk_timestamp2(Field *field, grn_obj *buf);
+#endif
 #ifdef MRN_HAVE_MYSQL_TYPE_DATETIME2
   int generic_store_bulk_datetime2(Field *field, grn_obj *buf);
 #endif
