@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # Copyright(C) 2010  Tetsuro IKEDA
-# Copyright(C) 2010-2018  Kouhei Sutou <kou@clear-code.com>
+# Copyright(C) 2010-2019  Kouhei Sutou <kou@clear-code.com>
 # Copyright(C) 2011  Kazuhiko
 #
 # This library is free software; you can redistribute it and/or
@@ -78,14 +78,25 @@ if [ "${mariadb}" = "yes" ]; then
   if [ "${MRN_BUNDLED}" != "TRUE" ]; then
     mariadb_mroonga_plugin_dir="${MYSQL_BUILD_DIR}/plugin/mroonga"
     if [ ! -e "${mariadb_mroonga_plugin_dir}" ]; then
-      ln -s "${top_build_dir}" "${mariadb_mroonga_plugin_dir}"
+      if [ -d "${top_build_dir}/.libs" ]; then
+        ln -s "${top_build_dir}/.libs" "${mariadb_mroonga_plugin_dir}"
+      else
+        ln -s "${top_build_dir}/" "${mariadb_mroonga_plugin_dir}"
+      fi
     fi
   fi
   plugins_dir=
 elif [ "${percona}" = "yes" ]; then
   plugins_dir="${MYSQL_SOURCE_DIR}/lib/mysql/plugin"
 else
-  plugins_dir="${MYSQL_SOURCE_DIR}/lib/plugin"
+  case ${MYSQL_VERSION} in
+    8.*)
+      plugins_dir="${MYSQL_BUILD_DIR}/lib/plugin"
+      ;;
+    *)
+      plugins_dir="${MYSQL_SOURCE_DIR}/lib/plugin"
+      ;;
+  esac
 fi
 
 same_link_p()
@@ -221,8 +232,10 @@ if [ -z "$test_suite_names" ]; then
 fi
 
 mysql_test_run_args=""
-if [ "${percona}" != "yes" ]; then
-  mysql_test_run_args="${mysql_test_run_args} --mem"
+if [ -z "${CI}" ]; then
+  if [ "${percona}" != "yes" ]; then
+    mysql_test_run_args="${mysql_test_run_args} --mem"
+  fi
 fi
 mysql_test_run_args="${mysql_test_run_args} --parallel=${n_processors}"
 mysql_test_run_args="${mysql_test_run_args} --retry=1"
